@@ -1,6 +1,6 @@
 /* praat_script.cpp
  *
- * Copyright (C) 1993-2023 Paul Boersma
+ * Copyright (C) 1993-2024 Paul Boersma
  *
  * This code is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -544,8 +544,8 @@ void praat_executeScriptFromFile (MelderFile file, conststring32 arguments, Edit
 	try {
 		autostring32 text = MelderFile_readText (file);
 		{// scope
-			autoMelderSaveDefaultDir saveDir;
-			autoMelderFileSetDefaultDir dir (file);   // so that script-relative file names can be used for including include files
+			autoMelderSaveCurrentFolder saveFolder;
+			autoMelderFileSetCurrentFolder folder (file);   // so that script-relative file names can be used for including include files
 			Melder_includeIncludeFiles (& text);
 		}   // back to the default directory of the caller
 		autoInterpreter interpreter = Interpreter_createFromEnvironment (optionalInterpreterOwningEditor);
@@ -553,7 +553,7 @@ void praat_executeScriptFromFile (MelderFile file, conststring32 arguments, Edit
 			Interpreter_readParameters (interpreter.get(), text.get());
 			Interpreter_getArgumentsFromString (interpreter.get(), arguments);   // interpret caller-relative paths for infile/outfile/folder arguments
 		}
-		autoMelderFileSetDefaultDir dir (file);   // so that script-relative file names can be used inside the script
+		autoMelderFileSetCurrentFolder folder (file);   // so that script-relative file names can be used inside the script
 		Interpreter_run (interpreter.get(), text.get(), false);
 	} catch (MelderError) {
 		Melder_throw (U"Script ", file, U" not completed.");
@@ -581,14 +581,14 @@ void praat_runScript (conststring32 fileName, integer narg, Stackel args, Editor
 			   will be interpreted relative to the caller's folder again.
 		*/
 		{// scope
-			autoMelderSaveDefaultDir saveDir;
-			autoMelderFileSetDefaultDir dir (& file);   // so that callee-relative file names can be used for including include files
+			autoMelderSaveCurrentFolder saveFolder;
+			autoMelderFileSetCurrentFolder folder (& file);   // so that callee-relative file names can be used for including include files
 			Melder_includeIncludeFiles (& text);
 		}   // back to the default directory of the caller
 		autoInterpreter interpreter = Interpreter_createFromEnvironment (optionalInterpreterOwningEditor);
 		Interpreter_readParameters (interpreter.get(), text.get());
 		Interpreter_getArgumentsFromArgs (interpreter.get(), narg, args);   // interpret caller-relative paths for infile/outfile/folder arguments
-		autoMelderFileSetDefaultDir dir (& file);   // so that callee-relative file names can be used inside the script
+		autoMelderFileSetCurrentFolder folder (& file);   // so that callee-relative file names can be used inside the script
 		Interpreter_run (interpreter.get(), text.get(), false);
 	} catch (MelderError) {
 		Melder_throw (U"Script ", & file, U" not completed.");   // don't refer to 'fileName', because its contents may have changed
@@ -601,14 +601,14 @@ void praat_executeScriptFromCommandLine (conststring32 fileName, integer argc, c
 	try {
 		autostring32 text = MelderFile_readText (& file);
 		{// scope
-			autoMelderSaveDefaultDir saveDir;
-			autoMelderFileSetDefaultDir dir (& file);   // so that script-relative file names can be used for including include files
+			autoMelderSaveCurrentFolder saveFolder;
+			autoMelderFileSetCurrentFolder folder (& file);   // so that script-relative file names can be used for including include files
 			Melder_includeIncludeFiles (& text);
 		}   // back to the default directory of the caller
 		autoInterpreter interpreter = Interpreter_createFromEnvironment (nullptr);
 		Interpreter_readParameters (interpreter.get(), text.get());
 		Interpreter_getArgumentsFromCommandLine (interpreter.get(), argc, argv);   // interpret caller-relative paths for infile/outfile/folder arguments
-		autoMelderFileSetDefaultDir dir (& file);   // so that script-relative file names can be used inside the script
+		autoMelderFileSetCurrentFolder folder (& file);   // so that script-relative file names can be used inside the script
 		Interpreter_run (interpreter.get(), text.get(), false);
 	} catch (MelderError) {
 		Melder_throw (U"Script ", & file, U" not completed.");   // don't refer to 'fileName', because its contents may have changed
@@ -676,7 +676,7 @@ static void secondPassThroughScript (UiForm sendingForm, integer /* narg */, Sta
 	structMelderFile file { };
 	Melder_pathToFile (sendingForm -> scriptFilePath.get(), & file);
 	autostring32 text = MelderFile_readText (& file);
-	autoMelderFileSetDefaultDir dir (& file);
+	autoMelderFileSetCurrentFolder folder (& file);
 	Melder_includeIncludeFiles (& text);
 	autoInterpreter interpreter = Interpreter_createFromEnvironment (optionalInterpreterOwningEditor);
 	Interpreter_readParameters (interpreter.get(), text.get());
@@ -689,7 +689,7 @@ static void firstPassThroughScript (MelderFile file, Editor optionalInterpreterO
 	try {
 		autostring32 text = MelderFile_readText (file);
 		{// scope
-			autoMelderFileSetDefaultDir dir (file);
+			autoMelderFileSetCurrentFolder folder (file);
 			Melder_includeIncludeFiles (& text);
 		}
 		autoInterpreter interpreter = Interpreter_createFromEnvironment (optionalInterpreterOwningEditor);
